=======
History
=======

0.1.8 (2019-03-27)
------------------
- removed function: get_downset_connections from module hddata
- improved desecription for better search results with "pip search pyhasse"

0.1.7 (2019-03-24)
------------------

- README improved
- tests for order module added
- URL for repository added
  
0.1.6 (2019-03-09)
------------------

- README improved
- Classifier added

0.1.5 (2019-03-05)
------------------

- set long_description_content_type to text/x-rst

0.1.4 (2018-12-26)
------------------

- css class removed from output as HTML table, best output for Jupyter notebooks

0.1.3 (2018-12-22)
------------------

- new test for CSV import with hypothesis

0.1.2 (2018-12-03)
------------------
- license changed to MIT
- changed the format of the date in this file

0.1.1 (2018-11-29)
------------------

- documentation improved

0.1.0 (2018-11-06)
------------------

- first release

